read_smf_stream

Function read_smf_stream 

pub fn read_smf_stream(
    cx: &mut Cx,
    path: impl AsRef<Path>,
    max_events: usize,
    metadata: StreamMetadata,
) -> Result<StreamValue>
Reads a Standard MIDI File from path and opens it as a MIDI stream.

The read is gated by the filesystem read capability and recorded as a KERNEL 6 filesystem effect. Events are packetized at most max_events per packet.