pub fn write_smf_stream(
cx: &mut Cx,
path: impl AsRef<Path>,
stream: &StreamValue,
tpq: u32,
) -> Result<usize>Expand description
Drains a MIDI stream and writes it to path as a Standard MIDI File.
The write is gated by the filesystem write capability and recorded as a KERNEL 6 filesystem effect. Returns the number of events written.