write_wav_stream

Function write_wav_stream 

pub fn write_wav_stream(
    cx: &mut Cx,
    path: impl AsRef<Path>,
    stream: &StreamValue,
    spec: PcmSpec,
) -> Result<PcmPumpSummary>
Drains a PCM stream and writes it to path as a canonical PCM16 WAV file.

The write is gated by the filesystem write capability and recorded as a KERNEL 6 filesystem effect. Returns a summary of the pumped PCM.